@@ -40,8 +40,7 @@ KService::List KOCore::availablePlugins(const QString &type, int version)
 {
     QString constraint;
     if (version >= 0) {
-        constraint
-            = QStringLiteral("[X-KDE-PluginInterfaceVersion] == %1").arg(QString::number(version));
+        constraint = QStringLiteral("[X-KDE-PluginInterfaceVersion] == %1").arg(QString::number(version));
     }
 
     return KServiceTypeTrader::self()->query(type, constraint);
@@ -49,14 +48,12 @@ KService::List KOCore::availablePlugins(const QString &type, int version)
 
 KService::List KOCore::availablePlugins()
 {
-    return availablePlugins(CalendarSupport::Plugin::serviceType(),
-                            CalendarSupport::Plugin::interfaceVersion());
+    return availablePlugins(CalendarSupport::Plugin::serviceType(), CalendarSupport::Plugin::interfaceVersion());
 }
 
 KService::List KOCore::availableCalendarDecorations()
 {
-    return availablePlugins(EventViews::CalendarDecoration::Decoration::serviceType(),
-                            EventViews::CalendarDecoration::Decoration::interfaceVersion());
+    return availablePlugins(EventViews::CalendarDecoration::Decoration::serviceType(), EventViews::CalendarDecoration::Decoration::interfaceVersion());
 }
 
 KService::List KOCore::availableParts()
@@ -103,8 +100,7 @@ CalendarSupport::Plugin *KOCore::loadPlugin(const QString &name)
     return nullptr;
 }
 
-EventViews::CalendarDecoration::Decoration *KOCore::loadCalendarDecoration(
-    const KService::Ptr &service)
+EventViews::CalendarDecoration::Decoration *KOCore::loadCalendarDecoration(const KService::Ptr &service)
 {
     KPluginLoader loader(*service);
     auto factory = loader.instance();
@@ -126,7 +122,7 @@ EventViews::CalendarDecoration::Decoration *KOCore::loadCalendarDecoration(
 
 EventViews::CalendarDecoration::Decoration *KOCore::loadCalendarDecoration(const QString &name)
 {
-    KService::List list = availableCalendarDecorations();
+    const KService::List list = availableCalendarDecorations();
     KService::List::ConstIterator it;
     KService::List::ConstIterator end(list.constEnd());
     for (it = list.constBegin(); it != end; ++it) {
@@ -153,8 +149,7 @@ KOrg::Part *KOCore::loadPart(const KService::Ptr &service, KOrg::MainWindow *par
         return nullptr;
     }
 
-    auto *pluginFactory
-        = static_cast<KOrg::PartFactory *>(factory);
+    auto pluginFactory = static_cast<KOrg::PartFactory *>(factory);
 
     if (!pluginFactory) {
         qCDebug(KORGANIZER_LOG) << "Cast failed";
@@ -191,10 +186,9 @@ KXMLGUIClient *KOCore::xmlguiClient(QWidget *wdg) const
 
 KOrg::Part *KOCore::loadPart(const QString &name, KOrg::MainWindow *parent)
 {
-    KService::List list = availableParts();
-    KService::List::ConstIterator it;
+    const KService::List list = availableParts();
     KService::List::ConstIterator end(list.constEnd());
-    for (it = list.constBegin(); it != end; ++it) {
+    for (KService::List::ConstIterator it = list.constBegin(); it != end; ++it) {
         if ((*it)->desktopEntryName() == name) {
             return loadPart(*it, parent);
         }
@@ -205,7 +199,7 @@ KOrg::Part *KOCore::loadPart(const QString &name, KOrg::MainWindow *parent)
 EventViews::CalendarDecoration::Decoration::List KOCore::loadCalendarDecorations()
 {
     if (!mCalendarDecorationsLoaded) {
-        QStringList selectedPlugins = KOPrefs::instance()->mSelectedPlugins;
+        const QStringList selectedPlugins = KOPrefs::instance()->mSelectedPlugins;
 
         mCalendarDecorations.clear();
         const KService::List plugins = availableCalendarDecorations();
@@ -230,12 +224,11 @@ KOrg::Part::List KOCore::loadParts(KOrg::MainWindow *parent)
 {
     KOrg::Part::List parts;
 
-    QStringList selectedPlugins = KOPrefs::instance()->mSelectedPlugins;
+    const QStringList selectedPlugins = KOPrefs::instance()->mSelectedPlugins;
 
     const KService::List plugins = availableParts();
-    KService::List::ConstIterator it;
     const KService::List::ConstIterator end(plugins.constEnd());
-    for (it = plugins.constBegin(); it != end; ++it) {
+    for (KService::List::ConstIterator it = plugins.constBegin(); it != end; ++it) {
         if (selectedPlugins.contains((*it)->desktopEntryName())) {
             KOrg::Part *part = loadPart(*it, parent);
             if (part) {
