@@ -92,7 +92,7 @@ void KOrganizerPlugin::select()
 OrgKdeKorganizerCalendarInterface *KOrganizerPlugin::interface()
 {
     if (!mIface) {
-        part();
+        (void) part();
     }
     Q_ASSERT(mIface);
     return mIface;
