@@ -14,12 +14,13 @@
 
 #include <KCalendarCore/Todo>
 
-#include <KontactInterface/Summary>
 #include <Akonadi/Calendar/ETMCalendar>
+#include <KontactInterface/Summary>
 
 class TodoPlugin;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class IncidenceChanger;
 }
 
@@ -31,7 +32,7 @@ class TodoSummaryWidget : public KontactInterface::Summary
     Q_OBJECT
 
 public:
-    TodoSummaryWidget(TodoPlugin *plugin, QWidget *parent);
+    explicit TodoSummaryWidget(TodoPlugin *plugin, QWidget *parent);
     ~TodoSummaryWidget() override;
 
     int summaryHeight() const override
@@ -44,7 +45,7 @@ public:
 public Q_SLOTS:
     void updateSummary(bool force = false) override
     {
-        Q_UNUSED(force);
+        Q_UNUSED(force)
         updateView();
     }
 
